##  Clustering
Clustering allows grouping of Fact Sheets based on Relations, Fields and Tags. Clustering makes it easier for you to organize and understand information. It helps you see patterns and relationships more clearly, making it simpler to grasp the structure of your IT landscape.
To apply clustering based on different criteria, go to Report's Settings and from the Cluster by drop down menu choose the needed criteria.
![Clustering](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274af5b77a44101481d3b92e3c8f2be2_LowRes.gif)
Clustering
In Landscape Reports it is possible to cluster by so-called 'self-referencing' relations: relations to subtypes of the same Fact Sheet type. That means, you can cluster by 'Children', 'Predecessors', 'Successors', and all other direct relations.
